Backtest
========

Runner (Convenience Functions)
------------------------------

.. automodule:: quaver.backtest.runner
   :members:
   :undoc-members:
   :show-inheritance:

Engine (Single-Asset)
---------------------

.. automodule:: quaver.backtest.engine
   :members:
   :undoc-members:
   :show-inheritance:

Multi-Asset Engine
------------------

.. automodule:: quaver.backtest.multi_engine
   :members:
   :undoc-members:
   :show-inheritance:

Portfolio
---------

.. automodule:: quaver.backtest.portfolio
   :members:
   :undoc-members:
   :show-inheritance:

Result
------

.. automodule:: quaver.backtest.result
   :members:
   :undoc-members:
   :show-inheritance:

Data Utilities
--------------

.. automodule:: quaver.backtest.data
   :members:
   :undoc-members:
   :show-inheritance:
